/*
 * Detect a Library for hardware detection
 *
 * Copyright (C) 1998-2000 MandrakeSoft
 * Copyright (C) 2005 Alexandre Dussart
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "detect.h"
#include "utils.h"
#include "serial.h"

/* mouse_detect: Detect mouses.		                              */
/************************** USB MOUSE  ******************************/
/************************** PS2 MOUSE  ******************************/
void mouse_detect(void){
	FILE *f;
	char *line=NULL;
	size_t len = 0;
	int mouse_num, event_num;

	if(debug)
		printf("\tProbing USB and PS/2 mouse...\n");

	if ((f = fopen("/proc/bus/input/devices", "r"))){
		while (getline(&line, &len, f) >= 0) {	
			char *vendor=NULL;  /* vendor name of the mouse */
			char *model=NULL;   /* model name of the mouse  */
			char *device=NULL;  /* device name of the mouse */
			char *mtype=NULL;  /* type of the mouse */
			if (strncmp(line, "N: Name=", 8)!=0)
				continue;
			if(strstr(line, "mouse")==NULL &&
			   strstr(line, "Mouse")==NULL &&
			   strstr(line, "Pad")==NULL) 
				continue;

			/* got mouse entry */
			model = strdup(line + 9);
			strtok(model, "\"");
			vendor = s_unknown;
			while((getline(&line, &len, f) >= 0) && (strncmp(line, "P: Phys=", 8)))
				; /* seek to the P entry */
			if (strstr(line, "usb"))
				mtype="Type:USB-mouse|"; /*Dougal: no newline!*/
			else
				mtype="Type:PS2-mouse|"; /*Dougal: no newline!*/
			while((getline(&line,&len,f)>=0) && strncmp(line,"H: Handlers=", 12))
				; /* seek to the H entry */
			if (sscanf(line,"H: Handlers=mouse%d event%d", &mouse_num, &event_num) != 2)
				device = "/dev/input/mice";
			else			/* build device string */
				device = "Not Available";

			printf("%sPort:%s\n",mtype, device); /*Dougal*/  

			if(debug)
				printf("\t\tFound %s %s\n", vendor, model);

			if (model) free(model);
		}
		free(line);
		fclose(f);
	}
}
